# Okta Integration for SaaS Discovery
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/okta-integration-for-saas-discovery#introduction)
  * [Implementation Details](https://help.sap.com/docs/leanix/ea/okta-integration-for-saas-discovery#implementation-details)
  * [Discovery Capabilities](https://help.sap.com/docs/leanix/ea/okta-integration-for-saas-discovery#discovery-capabilities)
  * [Setting up Okta Integration](https://help.sap.com/docs/leanix/ea/okta-integration-for-saas-discovery#setting-up-okta-integration)
  * [Enable API Service Integration in Okta](https://help.sap.com/docs/leanix/ea/okta-integration-for-saas-discovery#enable-api-service-integration-in-okta)
  * [Enter the Copied Credentials in SAP LeanIX](https://help.sap.com/docs/leanix/ea/okta-integration-for-saas-discovery#enter-the-copied-credentials-in-sap-leanix)


Configure the SAP LeanIX-Okta integration to automatically discover and manage SaaS applications.
